@@ -16,8 +16,8 @@ class Discussion(DoubanApiBase):
     def new(self, target, target_id, title, content):
         return self._post('/v2/%s/%s/discussions'%(target, target_id), title=title, content=content)
 
-    def list(self, target, target_id):
-        return self._get('/v2/%s/%s/discussions'%(target, target_id))
+    def list(self, target, target_id, start=DEFAULT_START, count=DEFAULT_COUNT):
+        return self._get('/v2/%s/%s/discussions'%(target, target_id), start=start, count=count)
 
     def update(self, id, title, content):
         return self._put('/v2/discussion/%s'%id, title=title, content=content)
