@@ -12,9 +12,9 @@ SCOPE_MAP = {
              'music': ['music_basic_r', 'music_basic_w'],
              'movie': ['movie_basic_r', 'movie_basic_w'],
              'book': ['book_basic_r', 'book_basic_w'],
-             'event': ['event_basic_r', 'event_basic_w'],
+             'event': ['event_basic_r', 'event_basic_w,event_advanced_r'],
             }
 
 SCOPE = ','.join(reduce(lambda x, y: x + y, SCOPE_MAP.values()))
 
-TOKEN = '03a599c20b8585310af0cd4622908f93'
+TOKEN = '' #'0e6e7d9c101228e52b4b78d430367aaf'
